﻿using System;
using System.ComponentModel;
using System.Collections.Generic;
using System.Diagnostics;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.Data.Services.Client;
using XamListApp.INETAService;
using System.Linq;


namespace XamListApp
{
    public class MainViewModel : INotifyPropertyChanged
    {
        public MainViewModel()
        {
            this.Authors = new DataServiceCollection<LiveAuthor>();
        }

        INETALivePublic context;

        private DataServiceCollection<LiveAuthor> authors;

        public DataServiceCollection<LiveAuthor> Authors
        {
            get { return authors; }
            set
            {
                authors = value;
                authors.LoadCompleted += new EventHandler<LoadCompletedEventArgs>(authors_LoadCompleted);
                NotifyPropertyChanged("Authors");
            }
        }

        public bool IsDataLoaded { get; private set; }

        /// <summary>
        /// Load data.
        /// </summary>
        public void LoadData()
        {
            context = new INETALivePublic(new Uri("http://live.ineta.org/InetaLiveService.svc/"));
            Authors = new DataServiceCollection<LiveAuthor>(context);
            var query = from auths in context.LiveAuthors.Expand("LivePresentations") select auths;
            Authors.LoadAsync(query);
        }

        void authors_LoadCompleted(object sender, LoadCompletedEventArgs e)
        {
            if (Authors.Continuation != null)
            {
                Authors.LoadNextPartialSetAsync();
            }
            IsDataLoaded = true;
        }

        public event PropertyChangedEventHandler PropertyChanged;
        private void NotifyPropertyChanged(String propertyName)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (null != handler)
            {
                handler(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}
namespace XamListApp.INETAService
{
    public partial class LiveAuthor : global::System.ComponentModel.INotifyPropertyChanged
    {
        
        /// <summary>
        /// Added Image property
        /// </summary>
        [System.CodeDom.Compiler.GeneratedCodeAttribute("System.Data.Services.Design", "1.0.0")]
        public string Image
        {
            get
            {
                return "/XamListApp;component/speaker.png";
            }
        }
    }
}